Environment

Struct Environment 

pub struct Environment {
    pub shape: EarthShape,
    pub atmosphere: Atmosphere,
    pub wavelength: f64,
}
Structure storing the shape of the underlying world and the atmospheric model.

Fields

shape: EarthShapeatmosphere: Atmospherewavelength: f64

Implementations

Source

impl Environment

pub fn n(&self, h: f64) -> f64

Returns the refractive index of the air at the given altitude.

pub fn dn(&self, h: f64) -> f64

Returns the derivative of the refractive index of the air with respect to the altitude, at the given altitude

pub fn radius(&self) -> Option<f64>

Returns Some(radius in meters) if the planet model is spherical, or None if it’s flat.

pub fn cast_ray<'a>( &'a self, start_h: f64, start_ang: f64, straight: bool, ) -> Box<dyn Path<'a> + 'a>

Returns an object representing a light path.

The path is defined by 3 parameters:

  • start_h - the starting altitude of the path in meters
  • start_ang - the initial angle in radians between the path and the horizontal plane; -π/2 is down, 0 is horizontal, π/2 is up
  • straight - true if the path should be a straight line, false if it should be a ray affected by the atmosphere
pub fn cast_ray_stepper<'a>( &'a self, start_h: f64, start_ang: f64, straight: bool, ) -> Box<dyn PathStepper<Item = RayState> + 'a>

Returns an object representing a light path.

The path is defined by 3 parameters:

  • start_h - the starting altitude of the path in meters
  • start_ang - the initial angle in radians between the path and the horizontal plane; -π/2 is down, 0 is horizontal, π/2 is up
  • straight - true if the path should be a straight line, false if it should be a ray affected by the atmosphere
pub fn cast_ray_target<'a>( &'a self, start_h: f64, tgt_h: f64, tgt_dist: f64, straight: bool, ) -> Box<dyn Path<'a> + 'a>

Returns an object representing a light path.

Instead of using the initial angle, this method chooses a ray that will hit a given target. The target is defined as distance and altitude.

  • start_h - the initial altitude of the path in meters
  • tgt_h - the altitude of the target point in meters
  • tgt_dist - the distance of the target point from the initial point, in meters
  • straight - true if the path should be a straight line, false if it should be a ray affected by the atmosphere

The ray is calculated by performing a binary search on the initial angle.