pub trait Path<'a> {
// Required methods
fn h_at_dist(&self, dist: f64) -> f64;
fn angle_at_dist(&self, dist: f64) -> f64;
fn into_path_stepper(self) -> Box<dyn PathStepper<Item = RayState> + 'a>;
}Expand description
The trait representing a light path.
Required Methods
Sourcefn h_at_dist(&self, dist: f64) -> f64
fn h_at_dist(&self, dist: f64) -> f64
Returns the altitude (in meters) at which the path is passing at the given distance (in meters) from the initial point.
Sourcefn angle_at_dist(&self, dist: f64) -> f64
fn angle_at_dist(&self, dist: f64) -> f64
Returns the angle (in radians) between the path and the horizontal plane at the given distance (in meters) from the initial point.
Sourcefn into_path_stepper(self) -> Box<dyn PathStepper<Item = RayState> + 'a>
fn into_path_stepper(self) -> Box<dyn PathStepper<Item = RayState> + 'a>
Returns a “stepper” - an iterator that performs one integration step along the path on
every call to next()